
' This file contains the macros to add or remove settings of sidebar components.
' See docs.odt for more detail.

Const CONFIG_DECK = "/org.openoffice.Office.UI.Sidebar/Content/DeckList"
Const CONFIG_PANEL = "/org.openoffice.Office.UI.Sidebar/Content/PanelList"
Const CONFIG_CUSTOM = "/mytools.UI.SidebarsByMacros/Content/Imples"


Sub AddSidebarItemForMacro(sResourceURI as string, sURI1 as string)
  config = GetConfigurationByName(CONFIG_CUSTOM)
  if not config.hasByName(sResourceURI) then
    item = config.createInstance()
    config.insertByName(sResourceURI, item)
  else
    item = config.getByName(sResourceURI)
  end if
  item.Initialize = sURI1
  config.commitChanges()
End Sub

Sub RemoveSidebarItemForMacro(sResourceURI as string)
  RemoveItemFromConfiguration(CONFIG_CUSTOM, sResourceURI)
End Sub


Sub AddDeck( _
    sName As String, sTitle As String, sId As String, _
    sIconURL As String, sHighContrastIconURL As String, _
    aContextList as Variant, nOrderIndex as integer )
  
  config = GetConfigurationByName(CONFIG_DECK)
  if not config.hasByName(sName) then
    item = config.createInstance()
    config.insertByName(sName, item)
  else
    item = config.getByName(sName)
  end if
    item.Title = sTitle
    item.Id = sId
    item.IconURL = sIconURL
    item.HighContrastIconURL = sHighContrastIconURL
    item.ContextList = aContextList
    item.OrderIndex = nOrderIndex
    config.commitChanges()
End Sub

Sub RemoveDeck( sName as string )
  RemoveItemFromConfiguration(CONFIG_DECK, sName)
End Sub

Sub AddPanel(_
    sName As String, sTitle as String, bTitleBarIsOptional as boolean, _
    sId as string, sDeckId as string, aContextList as Variant, _
    sImplementationURL as string, nOrderIndex as integer )
  
  config = GetConfigurationByName(CONFIG_PANEL)
  if not config.hasByName(sName) then
    item = config.createInstance()
    config.insertByName(sName, item)
  else
    item = config.getByName(sName)
  end if
    item.Title = sTitle
    item.TitleBarIsOptional = bTitleBarIsOptional
    item.Id = sId
    item.DeckId = sDeckId
    item.ContextList = aContextList
    item.ImplementationURL = sImplementationURL
    item.OrderIndex = nOrderIndex
    config.commitChanges()
End Sub

Sub RemovePanel( sName as string )
  RemoveItemFromConfiguration(CONFIG_PANEL, sName)
End Sub


Function GetConfigurationByName(sNodePath as string)
  Dim args(0) as new com.sun.star.beans.PropertyValue
  args(0).Name = "nodepath"
  args(0).Value = sNodePath
  GetConfigurationByName = CreateUnoService("com.sun.star.configuration.ConfigurationProvider")._
    createInstanceWithArguments(_
      "com.sun.star.configuration.ConfigurationUpdateAccess", args)
End Function

Function RemoveItemFromConfiguration(sNodePath as string, sName as string) As Boolean
  bState = False
  config = GetConfigurationByName(sNodePath)
  if config.hasByName(sName) then
    config.removeByName(sName)
    config.commitChanges()
    bState = True
  end if
  RemoveItemFromConfiguration = bState
End Function
